netapp_ontap.models.volume_analytics API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_analytics`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeAnalyticsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeAnalytics object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `by_accessed_time: AnalyticsInfoByAccessedTime GET`

    File system analytics information, broken down by date of last access.

  `by_modified_time: AnalyticsInfoByModifiedTime GET`

    File system analytics information, broken down by date of last modification.

  `bytes_used: Size GET`

    Number of bytes used on-disk.

    Example: 15436648448

  `file_count: Size GET`

    Number of descendants.

    Example: 21134

  `files_scanned: Size GET`

    Number of files in the volume that the file system analytics initialization scan has processed. Only returned when the state is `initializing`.

    Example: 43002

  `incomplete_data: bool GET`

    Returns true if data collection is incomplete for this directory tree.

  `initialization: VolumeAnalyticsInitialization GET POST PATCH`

    The initialization field of the volume_analytics.

  `report_time: ImpreciseDateTime GET`

    Time of data collection.

    Example: 2024-11-06T18:57:15.000+0000

  `scan_progress: Size GET`

    Percentage of files in the volume that the file system analytics initialization scan has processed. Only returned when the state is `initializing`.

    Example: 17

  `scan_throttle_reason: VolumeAnalyticsScanThrottleReason GET POST PATCH`

    The scan_throttle_reason field of the volume_analytics.

  `state: str GET POST PATCH`

    File system analytics state of the volume. If this value is "on", ONTAP collects extra file system analytics information for all directories on the volume. There will be a slight impact to I/O performance to collect this information. If this value is "off", file system analytics information is not collected and not available to be viewed. If this value is "initializing", that means file system analytics was recently turned on, and the initialization scan to gather information for all existing files and directories is currently running. If this value is "initialization_paused", this means that the initialization scan is currently paused. If this value is 'unknown', this means that there was an internal error when determining the file system analytics state for the volume.

    Valid choices:

    - unknown
    - initializing
    - initialization_paused
    - off
    - on
  `subdir_count: Size GET`

    Number of sub-directories.

    Example: 35

  `supported: bool GET`

    This field indicates whether or not file system analytics is supported on the volume. If file system analytics is not supported, the reason will be specified in the "analytics.unsupported_reason" field.

  `total_files: Size GET`

    Total number of files in the volume that the file system analytics initialization scan will process. Only returned when the state is `initializing`.

    Example: 101890

  `unsupported_reason: VolumeAnalyticsUnsupportedReason GET POST PATCH`

    The unsupported_reason field of the volume_analytics.